
ActiveClass
===========


.. automodule:: opendssdirect.ActiveClass
            :members:
            :undoc-members:
            :show-inheritance:

.. function:: opendssdirect.ActiveClass.ActiveClassName

    Name of the active class

.. function:: opendssdirect.ActiveClass.AllNames

    All element names in the active class

.. function:: opendssdirect.ActiveClass.Count

    Number of elements in the active class; same as NumElements

.. function:: opendssdirect.ActiveClass.First

    Sets the first element in the active class to be the active object; if object is a CktElement, ActiveCktElement also points to this element; returns 0 if none

.. function:: opendssdirect.ActiveClass.Name

    Name of the active element of the active classSet the name of the active element of the active class

.. function:: opendssdirect.ActiveClass.Next

    Sets the next element in the active class to be the active object; if object is a CktElement, ActiveCktElement also points to this element; returns 0 if no more

.. function:: opendssdirect.ActiveClass.NumElements

    Number of elements in the active class

